/*******************************************************************@CM2CPYR*/
/*                                                                  @CM2CPYR*/
/*     Licensed Materials - Property of IBM                         @CM2CPYR*/
/*                                                                  @CM2CPYR*/
/*     5622-078                                                     @CM2CPYR*/
/*     (C) Copyright IBM Corp. 1988, 1995 All Rights Reserved.      @CM2CPYR*/
/*                                                                  @CM2CPYR*/
/*     US Government Users Restricted Rights - Use, duplication or  @CM2CPYR*/
/*     disclosure restricted by GSA ADP Schedule Contract with      @CM2CPYR*/
/*     IBM Corp.                                                    @CM2CPYR*/
/*                                                                  @CM2CPYR*/
/*******************************************************************@CM2CPYR*/
/*****************************************************************************/
/*                                                                           */
/*   Component   : Port Connection Manager (PCM)                             */
/*                                                                           */
/*   Module      : PCMDEF.H                                                  */
/*                                                                           */
/*   Description : This module contains definitions of symbols and           */
/*                 data structures used by the PCM.                          */
/*                                                                           */
/*****************************************************************************/

#define STACKSIZE     8192
#define FAILURE       TRUE
#ifndef SUCCESS
#define SUCCESS       FALSE
#endif
#define CR            13
#define LF            10
#define BACKSLASH     92
#define MAXDSTRLENGTH 256
#define EXLST_ORDER   0xC400    /* 196 so that our exit list runs after CM */
#define TC_EXCEPTION  4
#define PHONENUMBERLENGTH       50   /* Added for feature 5484 */

typedef struct pcmcb   far *PPCMCB;
typedef struct sap     far *PSAP;
typedef struct timer   far *PTIMER;
typedef struct port    far *PPORT;
typedef struct dstring far *PDSTRING;


typedef struct                  /** Port Flags **/
   {
      /* Port Flags */
      USHORT    PermConnection     : 1;
      USHORT    PhysConnActive     : 1;
      USHORT    DataConnActive     : 1;
      USHORT    PortInUse          : 1;
      /* Call Instance Flags */
      USHORT    CallClearRequested : 1;
      USHORT    CallAccepted       : 1;
      USHORT    Answering          : 1;
      USHORT    EncodingScheme     : 1;
   } PFLAGS;


typedef struct port             /** Port Structure **/
   {
      /* Port Variables */
      PPORT     pNextPort;
      USHORT    Status;
      USHORT    Phase;
      USHORT    State;
      PFLAGS    Flags;
      UCHAR     Name[16];
      UCHAR     LocalNum[32];
      PXVPPAT   pPPAT;
      PPCMCB    pPCMCB;
      /* Dialog Variables */
      USHORT    RspDataLength;
      PUCHAR    pRspData;
      PUSHORT   pRspGroup;
      USHORT    (far *pMatchArray)[];
      /* Call Instance Variables */
      ULONG     U_CI_ID;
      USHORT    RemoteNumLength;
      UCHAR     RemoteNum[50];     /** Changed for feature 5484 (from 32) */
      ULONG     ConnectSpeed;
      UCHAR     FramingStandard;
      UCHAR     Transparency;
      UCHAR     PrevTransparency;
      UCHAR     XIDCount;
   } PORT;


typedef struct dstring          /** Modem Dialog String Structure **/
   {
      PDSTRING  pNextDString;
      UCHAR     Name[16];
      USHORT    Length;
      UCHAR     Text[MAXDSTRLENGTH];
   } DSTRING;


typedef struct                  /** Action Structure **/
   {
      USHORT    Code;
      union
         {
            PDSTRING  pDString;
            PUSHORT   pRspGroup;
            USHORT    RetCode;
            USHORT    Seconds;
            USHORT    Reserved;
         } Parm;
   } ACTION, far *PACTION;


typedef struct                  /** Response Structure **/
   {
      USHORT    Code;
      union
         {
            PDSTRING  pDString;
            USHORT    Reserved;
         } Parm;
      PUSHORT   pActionGroup;
   } RESPONSE, far *PRESPONSE;


typedef struct sap              /** SAP Structure **/
   {
      USHORT    Status;
      ULONG     U_SAP_ID;
      USHORT (far pascal *Indicate)( PVOID );
      USHORT (far pascal *Confirm)( PVOID );
      PPCMCB    pPCMCB;
   } SAP;


typedef struct                  /** Dialog Structure **/
   {
      UCHAR     Name[16];
      PUSHORT   pActionGroup;
   } DIALOG, far *PDIALOG;


typedef struct                  /** PCM Flags **/
   {
      USHORT    GCCITraceActive   : 1;
      USHORT    SCPITraceActive   : 1;
      USHORT    EventTraceActive  : 1;
      USHORT    DialogTraceActive : 1;
      USHORT    Asynchronous      : 1;
      USHORT    Synchronous       : 1;
      USHORT    AutoBaudDetect    : 1;
      USHORT    FlowControl       : 1;
      USHORT    FlowControlType   : 1;
      USHORT    EncodingScheme    : 1;
   } PCMFLAGS;


typedef struct pcmcb            /** PCM Control Block **/
   {
      PPCMCB    pNextPCMCB;
      USHORT    Status;
      PCMFLAGS  Flags;
      UCHAR     PCMName[16];
      UCHAR     DDFName[13];
      PUSHORT   pDDT;
      SAP       CNMSAP;
      SAP       CMSAP;
      USHORT    ModemClass;
      UCHAR     FramingStandard;
      UCHAR     Transparency;
      ULONG     SerialPortSpeed;
      PPORT     pPortList;
      PDSTRING  pDStringList;
   } PCMCB;


typedef struct timer            /** Timer Structure **/
   {
      PTIMER    pNextTimer;
      USHORT    SecondsToGo;
      USHORT    TimerClass;
      PPORT     pPort;
   } TIMER;


typedef struct                  /** GCCI Primitive Structure **/
   {
      USHORT    CtrlInfoLength;
      USHORT    PrimitiveCode;
      USHORT    DataInfoLength;
      UCHAR     Selector;
      UCHAR     IDType;
      ULONG     Identifier;
   } GCCI, far *PGCCI;


typedef struct                  /** SCPI Primitive Structure **/
   {
      USHORT    FunctionCode;
      USHORT    RequestHandle;
      PPORT     pPort;
      USHORT    ReturnCode;
      USHORT    Word;
      ULONG     DoubleWord;
   } SCPI, far *PSCPI;


typedef struct prim far *PPRIM;
typedef PPRIM       far *PPPRIM;

typedef struct prim             /** Enqueued Primitive Structure **/
   {
      PPRIM     pNextPrim;
      USHORT    PrimType;
      union
         {
            GCCI   gcci;
            SCPI   scpi;
         } Prim;
   } PRIM;


/* Primitive Types */

#define PRIM_TYPE_GCCI   0
#define PRIM_TYPE_SCPI   1


/* IOCTL Function Codes */

#define VPCM_FC_INIT_PCM_DD     0x40
#define VPCM_FC_SCPI_PRIMITIVE  0x41
#define VPCM_FC_ENQUEUE_PRIM    0x42
#define VPCM_FC_DEQUEUE_PRIM    0x43
#define VPCM_FC_UPDATE_PCMCB    0x44


/* IOCTL Initialize PCM Device Driver Parameter Packet */

typedef struct
   {
      HSYSSEM   QueueSem;
      PPPRIM    pQueue;
   } INITDD, far *PINITDD;


#define GCCI_PCM_TIMEOUT  0xFFFF


/* Trace Point IDs */

#define TRACE_ID_GCCI_API  1
#define TRACE_ID_SCPI_API  2
#define TRACE_ID_EVENT     3
#define TRACE_ID_DIALOG    4


/* Modem Class */

/*  Defined in GCCI_COM.H       */
/*  MODEM_CLASS_UNSPECIFIED  0  */
/*  MODEM_CLASS_PROPRIETARY  1  */
/*  MODEM_CLASS_V22          2  */
/*  MODEM_CLASS_V22BIS       3  */
/*  MODEM_CLASS_V32          4  */
/*  MODEM_CLASS_V32BIS       5  */


/* FramingStandard */

#define FRAMING_ISO3309              1
#define FRAMING_AWP0224_WITH_NEG     2
#define FRAMING_AWP0224_WITHOUT_NEG  3


/* Transparency */

#define TRANSPARENCY_EIGHT_NONE      0
#define TRANSPARENCY_SEVEN_EVEN      1
#define TRANSPARENCY_SEVEN_ODD       2
#define TRANSPARENCY_SEVEN_MARK      3
/* Note: These are indexes into the XID array */


/* AutoBaudDetect */

#define ON  TRUE
#define OFF FALSE


/* FlowControlType */

#define RTSCTS  TRUE
#define XONXOFF FALSE


/* EncodingScheme */

#define NRZI TRUE
#define NRZ  FALSE


/* Status */

#define STATUS_DEACTIVATED   0
#define STATUS_ACTIVATING    1
#define STATUS_ACTIVATED     2
#define STATUS_DEACTIVATING  3


/* Timer Classes */

#define TIMER_CLASS_STATE_TIMER     0
#define TIMER_CLASS_RECV_XID_TIMER  1


/* Call Phases */

#define PHASE_ACTIVATING           1
#define PHASE_IDLE                 2
#define PHASE_IDENTIFYING          3
#define PHASE_ESTABLISHING         4
#define PHASE_CONFIGURING          5
#define PHASE_CLEARING             6
#define PHASE_DEACTIVATING         7
#define PHASE_REINITIALIZING       8


/* Call States */

#define STATE_WAIT_SET_PPAT_PARMS  1
#define STATE_WAIT_ACT_PHYS_CONN   2
#define STATE_IDLE                 3
#define STATE_WAIT_CALL_SETUP_RSP  4
#define STATE_WAIT_FOR_RESPONSE    5
#define STATE_WAIT_CONN_ACTIVE     6
#define STATE_WAIT_TO_SEND_XID     7
#define STATE_WAIT_TO_RECV_XID     8
#define STATE_CONNECTED            9
#define STATE_WAIT_CALL_CLEAR_RSP  10
#define STATE_WAIT_FOR_DELAY       11
#define STATE_WAIT_DEACT_PHYS_CONN 12


/* Timeouts */

#define TIMEOUT_WAIT_FOR_DELAY       1
#define TIMEOUT_WAIT_SET_PPAT_PARMS  5
#define TIMEOUT_WAIT_CALL_CLEAR_RSP  5
#define TIMEOUT_WAIT_CONN_ACTIVE     60
#define TIMEOUT_WAIT_ACT_PHYS_CONN   10
#define TIMEOUT_WAIT_DEACT_PHYS_CONN 10
#define TIMEOUT_WAIT_TO_SEND_XID     1
#define TIMEOUT_WAIT_TO_RECV_XID     60

#define TIMEOUT_SCPI_ACT_PHYS_CONN   (TIMEOUT_WAIT_ACT_PHYS_CONN - 2)*1000
#define TIMEOUT_SCPI_DEACT_PHYS_CONN (TIMEOUT_WAIT_DEACT_PHYS_CONN-2)*1000


/* Action Codes */

#define ACTION_EXIT_DIALOG        0
#define ACTION_WAIT_FOR_RESPONSE  1
#define ACTION_SEND_STRING        2
#define ACTION_SEND_DIAL_COMMAND  3
#define ACTION_START_TIMER        4
#define ACTION_STOP_TIMER         5
#define ACTION_INDICATE_RINGING   6


/* Response Codes */

#define RESPONSE_TIMEOUT          0
#define RESPONSE_RECEIVE_STRING   1
#define RESPONSE_RECEIVE_RATE     2
#define RESPONSE_RECEIVE_DELAY    3
#define RESPONSE_RECEIVE_PHONE    4


/* Exit Dialog Return Codes */

#define DIALOG_RC_SUCCESS         0
#define DIALOG_RC_NOT_RESPONDING  1
#define DIALOG_RC_ERROR           2
#define DIALOG_RC_NO_DIALTONE     3
#define DIALOG_RC_NO_CARRIER      4
#define DIALOG_RC_NO_ANSWER       5
#define DIALOG_RC_VOICE           6
#define DIALOG_RC_REMOTE_BUSY     7
#define DIALOG_RC_CIRCUIT_BUSY    8
#define DIALOG_RC_MODEM_BUSY      9
#define DIALOG_RC_DELAYED         10
#define DIALOG_RC_FORBIDDEN       11


/* Message Definitions */

#define MSG0    200
#define MSG1    (MSG0+1)
#define MSG2    (MSG0+2)
#define MSG3    (MSG0+3)
#define MSG4    (MSG0+4)
#define MSG5    (MSG0+5)
#define MSG6    (MSG0+6)
#define MSG7    (MSG0+7)
#define MSG8    (MSG0+8)
#define MSG9    (MSG0+9)
#define MSG10   (MSG0+10)
#define MSG11   (MSG0+11)
#define MSG12   (MSG0+12)
#define MSG13   (MSG0+13)
#define MSG14   (MSG0+14)
#define MSG15   (MSG0+15)
#define MSG16   (MSG0+16)
#define MSG17   (MSG0+17)
#define MSG18   (MSG0+18)
#define MSG19   (MSG0+19)
#define MSG20   (MSG0+20)
#define MSG21   (MSG0+21)
#define MSG22   (MSG0+22)
#define MSG23   (MSG0+23)
#define MSG24   (MSG0+24)
#define MSG25   (MSG0+25)
#define MSG26   (MSG0+26)
#define MSG27   (MSG0+27)
#define MSG28   (MSG0+28)
#define MSG29   (MSG0+29)
#define MSG30   (MSG0+30)
#define MSG31   (MSG0+31)
#define MSG32   (MSG0+32)
#define MSG33   (MSG0+33)
#define MSG34   (MSG0+34)
#define MSG35   (MSG0+35)
#define MSG36   (MSG0+36)
#define MSG37   (MSG0+37)
#define MSG38   (MSG0+38)
#define MSG39   (MSG0+39)
#define MSG40   (MSG0+40)
#define MSG90   (MSG0+90)     /* Added for DEFECT 1870 */
